@@ -55,12 +55,13 @@ var _ = Describe("command line tool flags", func() {
 	Context("yaml command", func() {
 		Context("creating yaml output", func() {
 			It("should not create YAML output that is not valid", func() {
-				filename := createTestFile(`{"foo":{"bar":"*"}}`)
+				filename := createTestFile(`{"a": ",", "foo": {"bar":"*"}}`)
 				defer os.Remove(filename)
 
 				out, err := dyff("yaml", filename)
 				Expect(err).ToNot(HaveOccurred())
 				Expect(out).To(BeEquivalentTo(`---
+a: ","
 foo:
   bar: "*"
 
