@@ -79,27 +79,54 @@ func KubernetesEntityDetection(value bool) CompareOption {
 // objects. In this case the representation of an input file, which might
 // contain multiple documents. It returns a report with the list of differences.
 func CompareInputFiles(from ytbx.InputFile, to ytbx.InputFile, compareOptions ...CompareOption) (Report, error) {
-	if len(from.Documents) != len(to.Documents) {
-		return Report{}, fmt.Errorf("comparing YAMLs with a different number of documents is currently not supported")
-	}
-
 	// initialize the comparator with the tool defaults
-	compare := compare{
+	cmpr := compare{
 		settings: compareSettings{
 			NonStandardIdentifierGuessCountThreshold: 3,
 			IgnoreOrderChanges:                       false,
-			KubernetesEntityDetection:                false,
+			KubernetesEntityDetection:                true,
 		},
 	}
 
 	// apply the optional compare options provided to this function call
 	for _, compareOption := range compareOptions {
-		compareOption(&compare.settings)
+		compareOption(&cmpr.settings)
 	}
 
-	result := make([]Diff, 0)
+	// in case Kubernetes mode is enabled, try to compare documents in the YAML
+	// file by their names rather than just by the order of the documents
+	if cmpr.settings.KubernetesEntityDetection {
+		for _, entry := range from.Documents {
+			name, err := fqrn(entry.Content[0])
+			if err == nil {
+				from.Names = append(from.Names, name)
+			}
+		}
+
+		for _, entry := range to.Documents {
+			name, err := fqrn(entry.Content[0])
+			if err == nil {
+				to.Names = append(to.Names, name)
+			}
+		}
+
+		// when the look-up of a name for each document in each file worked out, it
+		// means that the documents are most likely Kubernetes resources, so a comparison
+		// using the names can be done, otherwise, leave and continue with default behavior
+		if len(from.Names) == len(from.Documents) && len(to.Names) == len(to.Documents) {
+			if result, err := cmpr.documentNodes(from, to); err == nil {
+				return Report{from, to, result}, nil
+			}
+		}
+	}
+
+	if len(from.Documents) != len(to.Documents) {
+		return Report{}, fmt.Errorf("comparing YAMLs with a different number of documents is currently not supported")
+	}
+
+	var result []Diff
 	for idx := range from.Documents {
-		diffs, err := compare.objects(
+		diffs, err := cmpr.objects(
 			ytbx.Path{
 				Root:        &from,
 				DocumentIdx: idx,
@@ -125,7 +152,7 @@ func (compare *compare) objects(path ytbx.Path, from *yamlv3.Node, to *yamlv3.No
 
 	case (from == nil && to != nil) || (from != nil && to == nil):
 		return []Diff{{
-			path,
+			&path,
 			[]Detail{{
 				Kind: MODIFICATION,
 				From: from,
@@ -135,7 +162,7 @@ func (compare *compare) objects(path ytbx.Path, from *yamlv3.Node, to *yamlv3.No
 
 	case (from.Kind != to.Kind) || (from.Tag != to.Tag):
 		return []Diff{{
-			path,
+			&path,
 			[]Detail{{
 				Kind: MODIFICATION,
 				From: from,
@@ -172,7 +199,7 @@ func (compare *compare) nonNilSameKindNodes(path ytbx.Path, from *yamlv3.Node, t
 		default:
 			if from.Value != to.Value {
 				diffs, err = []Diff{{
-					path,
+					&path,
 					[]Detail{{
 						Kind: MODIFICATION,
 						From: from,
@@ -192,6 +219,124 @@ func (compare *compare) nonNilSameKindNodes(path ytbx.Path, from *yamlv3.Node, t
 	return diffs, err
 }
 
+func (compare *compare) documentNodes(from, to ytbx.InputFile) ([]Diff, error) {
+	var result []Diff
+
+	type doc struct {
+		node *yamlv3.Node
+		idx  int
+	}
+
+	var createDocumentLookUpMap = func(inputFile ytbx.InputFile) (map[string]doc, []string, error) {
+		var lookUpMap = make(map[string]doc)
+		var names []string
+
+		for i, document := range inputFile.Documents {
+			node := document.Content[0]
+
+			name, err := fqrn(node)
+			if err != nil {
+				return nil, nil, err
+			}
+
+			names = append(names, name)
+			lookUpMap[name] = doc{idx: i, node: node}
+		}
+
+		return lookUpMap, names, nil
+	}
+
+	fromLookUpMap, fromNames, err := createDocumentLookUpMap(from)
+	if err != nil {
+		return nil, err
+	}
+
+	toLookUpMap, toNames, err := createDocumentLookUpMap(to)
+	if err != nil {
+		return nil, err
+	}
+
+	removals := []*yamlv3.Node{}
+	additions := []*yamlv3.Node{}
+
+	for _, name := range fromNames {
+		var fromItem = fromLookUpMap[name]
+		if toItem, ok := toLookUpMap[name]; ok {
+			// `from` and `to` contain the same `key` -> require comparison
+			diffs, err := compare.objects(
+				ytbx.Path{Root: &from, DocumentIdx: fromItem.idx},
+				followAlias(fromItem.node),
+				followAlias(toItem.node),
+			)
+
+			if err != nil {
+				return nil, err
+			}
+
+			result = append(result, diffs...)
+
+		} else {
+			// `from` contain the `key`, but `to` does not -> removal
+			removals = append(removals, fromItem.node)
+		}
+	}
+
+	for _, name := range toNames {
+		var toItem = toLookUpMap[name]
+		if _, ok := fromLookUpMap[name]; !ok {
+			// `to` contains a `key` that `from` does not have -> addition
+			additions = append(additions, toItem.node)
+		}
+	}
+
+	diff := Diff{Details: []Detail{}}
+
+	if len(removals) > 0 {
+		diff.Details = append(diff.Details,
+			Detail{
+				Kind: REMOVAL,
+				From: &yamlv3.Node{
+					Kind:    yamlv3.DocumentNode,
+					Content: removals,
+				},
+				To: nil,
+			},
+		)
+	}
+
+	if len(additions) > 0 {
+		diff.Details = append(diff.Details,
+			Detail{
+				Kind: ADDITION,
+				From: nil,
+				To: &yamlv3.Node{
+					Kind:    yamlv3.DocumentNode,
+					Content: additions,
+				},
+			},
+		)
+	}
+
+	if !compare.settings.IgnoreOrderChanges && len(fromNames) == len(toNames) {
+		for i := range fromNames {
+			if fromNames[i] != toNames[i] {
+				diff.Details = append(diff.Details, Detail{
+					Kind: ORDERCHANGE,
+					From: AsSequenceNode(fromNames),
+					To:   AsSequenceNode(toNames),
+				})
+				break
+			}
+		}
+	}
+
+	if len(diff.Details) > 0 {
+		result = append([]Diff{diff}, result...)
+	}
+
+	return result, nil
+}
+
 func (compare *compare) mappingNodes(path ytbx.Path, from *yamlv3.Node, to *yamlv3.Node) ([]Diff, error) {
 	result := make([]Diff, 0)
 	removals := []*yamlv3.Node{}
@@ -227,7 +372,7 @@ func (compare *compare) mappingNodes(path ytbx.Path, from *yamlv3.Node, to *yaml
 		}
 	}
 
-	diff := Diff{Path: path, Details: []Detail{}}
+	diff := Diff{Path: &path, Details: []Detail{}}
 
 	if len(removals) > 0 {
 		diff.Details = append(diff.Details,
@@ -450,7 +595,7 @@ func (compare *compare) nodeValues(path ytbx.Path, from *yamlv3.Node, to *yamlv3
 	result := make([]Diff, 0)
 	if strings.Compare(from.Value, to.Value) != 0 {
 		result = append(result, Diff{
-			path,
+			&path,
 			[]Detail{{
 				Kind: MODIFICATION,
 				From: from,
@@ -535,7 +680,7 @@ func findOrderChangesInNamedEntryLists(fromNames, toNames []string) []Detail {
 
 func packChangesAndAddToResult(list []Diff, path ytbx.Path, orderchanges []Detail, additions, removals []*yamlv3.Node) ([]Diff, error) {
 	// Prepare a diff for this path to added to the result set (if there are changes)
-	diff := Diff{Path: path, Details: []Detail{}}
+	diff := Diff{Path: &path, Details: []Detail{}}
 
 	if len(orderchanges) > 0 {
 		diff.Details = append(diff.Details, orderchanges...)
@@ -687,7 +832,6 @@ func (compare *compare) getIdentifierFromNamedLists(listA, listB *yamlv3.Node) (
 // getIdentifierFromKubernetesEntityList returns 'metadata.name' as a field identifier if the provided objects all have the key.
 func getIdentifierFromKubernetesEntityList(listA, listB *yamlv3.Node) (ListItemIdentifierField, error) {
 	key := ListItemIdentifierField("metadata.name")
-
 	allHaveMetadataName := func(sequenceNode *yamlv3.Node) bool {
 		numWithMetadata := 0
 		for _, entry := range sequenceNode.Content {
@@ -701,12 +845,38 @@ func getIdentifierFromKubernetesEntityList(listA, listB *yamlv3.Node) (ListItemI
 		}
 		return numWithMetadata == len(sequenceNode.Content)
 	}
+
 	listAHasKey := allHaveMetadataName(listA)
 	listBHasKey := allHaveMetadataName(listB)
 	if listAHasKey && listBHasKey {
 		return key, nil
 	}
-	return "", fmt.Errorf("not all entities appear to have metadata.name fields")
+
+	return "", fmt.Errorf("not all entities appear to have %q fields", key)
+}
+
+// fqrn returns something like a fully qualified Kubernetes resource name, which contains its kind, namepace and name
+func fqrn(node *yamlv3.Node) (string, error) {
+	if node.Kind != yamlv3.MappingNode {
+		return "", fmt.Errorf("name look-up for Kubernetes resources does only work with mapping nodes")
+	}
+
+	kind, err := nameFromPath(node, "kind")
+	if err != nil {
+		return "", err
+	}
+
+	namespace, err := nameFromPath(node, "metadata.namespace")
+	if err != nil {
+		namespace = "default"
+	}
+
+	name, err := nameFromPath(node, "metadata.name")
+	if err != nil {
+		return "", err
+	}
+
+	return fmt.Sprintf("%s/%s/%s", kind, namespace, name), nil
 }
 
 func getNonStandardIdentifierFromNamedLists(listA, listB *yamlv3.Node, nonStandardIdentifierGuessCountThreshold int) ListItemIdentifierField {
@@ -920,7 +1090,7 @@ func ChangeRoot(inputFile *ytbx.InputFile, path string, useGoPatchPaths bool, tr
 
 	// Parse path string and create nicely formatted output path
 	if resolvedPath, err := ytbx.ParsePathString(path, originalRoot); err == nil {
-		path = pathToString(resolvedPath, useGoPatchPaths, multipleDocuments)
+		path = pathToString(&resolvedPath, useGoPatchPaths, multipleDocuments)
 	}
 
 	inputFile.Note = fmt.Sprintf("YAML root was changed to %s", path)
@@ -928,7 +1098,7 @@ func ChangeRoot(inputFile *ytbx.InputFile, path string, useGoPatchPaths bool, tr
 	return nil
 }
 
-func pathToString(path ytbx.Path, useGoPatchPaths bool, showPathRoot bool) string {
+func pathToString(path *ytbx.Path, useGoPatchPaths bool, showPathRoot bool) string {
 	var result string
 
 	if useGoPatchPaths {
@@ -938,7 +1108,7 @@ func pathToString(path ytbx.Path, useGoPatchPaths bool, showPathRoot bool) strin
 		result = styledDotStylePath(path)
 	}
 
-	if showPathRoot {
+	if path != nil && showPathRoot {
 		result += bunt.Sprintf("  LightSteelBlue{(%s)}", path.RootDescription())
 	}
 
