@@ -50,13 +50,12 @@ type stringWriter interface {
 
 // HumanReport is a reporter with human readable output in mind
 type HumanReport struct {
+	Report
+	MinorChangeThreshold float64
 	NoTableStyle         bool
 	DoNotInspectCerts    bool
 	OmitHeader           bool
 	UseGoPatchPaths      bool
-	MinorChangeThreshold float64
-
-	Report
 }
 
 // WriteReport writes a human readable report to the provided writer
@@ -130,7 +129,7 @@ func (report *HumanReport) generateHumanDiffOutput(output stringWriter, diff Dif
 	// For the use case in which only a path-less diff is suppose to be printed,
 	// omit the indent in this case since there is only one element to show
 	indent := 2
-	if len(diff.Path.PathElements) == 0 {
+	if diff.Path != nil && len(diff.Path.PathElements) == 0 {
 		indent = 0
 	}
 
@@ -189,6 +188,12 @@ func (report *HumanReport) generateHumanDetailOutputRemoval(detail Detail) (stri
 	var output bytes.Buffer
 
 	switch detail.From.Kind {
+	case yamlv3.DocumentNode:
+		_, _ = fmt.Fprint(&output, yellow("%c %s removed:\n",
+			REMOVAL,
+			text.Plural(len(detail.From.Content), "document"),
+		))
+
 	case yamlv3.SequenceNode:
 		text := text.Plural(len(detail.From.Content), "list entry", "list entries")
 		_, _ = output.WriteString(yellow("%c %s removed:\n", REMOVAL, text))
@@ -676,7 +681,11 @@ func CreateTableStyleString(separator string, indent int, columns ...string) str
 	return buf.String()
 }
 
-func styledGoPatchPath(path ytbx.Path) string {
+func styledGoPatchPath(path *ytbx.Path) string {
+	if path == nil {
+		return bunt.Sprintf("*(file level)*")
+	}
+
 	if path.PathElements == nil {
 		return bunt.Sprint("*/*")
 	}
@@ -699,7 +708,11 @@ func styledGoPatchPath(path ytbx.Path) string {
 	return strings.Join(sections, "/")
 }
 
-func styledDotStylePath(path ytbx.Path) string {
+func styledDotStylePath(path *ytbx.Path) string {
+	if path == nil {
+		return bunt.Sprintf("*(file level)*")
+	}
+
 	if path.PathElements == nil {
 		return bunt.Sprint("*(root level)*")
 	}
